@@ -59,7 +59,7 @@ def checkAndJoinMeeting():
     actions = ActionChains(browser)
     rosterBtn = wait_and_find_element_by_xpath(browser, '//button[@id="roster-button"]', timeOutDelay)
     actions.move_to_element(rosterBtn).click().perform()
-    numStr = wait_and_find_elements_by_xpath(browser, '//span[@class="toggle-number"][@ng-if="::ctrl.enableRosterParticipantsLimit"]')
+    numStr = wait_and_find_elements_by_xpath(browser, '//span[@class="toggle-number"][@ng-if="::ctrl.enableRosterParticipantsLimit"]', timeOutDelay)
     if len(numStr) >= 2:
         if numStr[1].text[1:-1] != '':
             maxParticipants = curParticipants = int(numStr[1].text[1:-1])
@@ -69,7 +69,7 @@ def checkAndEndOrLeaveOrJoinMeeting():
     hangupBtn = wait_and_find_element_by_xpath(browser, '//button[@id="hangup-button"]', 2)
     if hangupBtn != None: # currently in meeting
         print_msg("in a meeting", "DEBUG")
-        numStr = wait_and_find_elements_by_xpath(browser, '//span[@class="toggle-number"][@ng-if="::ctrl.enableRosterParticipantsLimit"]')
+        numStr = wait_and_find_elements_by_xpath(browser, '//span[@class="toggle-number"][@ng-if="::ctrl.enableRosterParticipantsLimit"]', timeOutDelay)
         if len(numStr) >= 2:
             if numStr[1].text[1:-1] != '':
                 curParticipants = int(numStr[1].text[1:-1])
@@ -92,7 +92,11 @@ def checkAndEndOrLeaveOrJoinMeeting():
         print_msg("not in a meeting, looking for a meeting to join...", "DEBUG")
         maxParticipants = curParticipants = 0
         browser.get('https://teams.microsoft.com/_#/calendarv2')
-        checkAndJoinMeeting()
+        try:
+            checkAndJoinMeeting()
+        except Exception as e:
+            print_msg(e, "DEBUG")
+            browser.get('https://teams.microsoft.com/_#/calendarv2')
 
 def init(step=0):
     global minParticipants
@@ -153,10 +157,10 @@ def main():
             try:
                 print_msg("checking for meeting activity...", "INFO")
                 checkAndEndOrLeaveOrJoinMeeting()
-            except:
+            except Exception as e:
+                print_msg(e, "DEBUG")
                 print_msg("failed to check meeting activity", "WARNING")
-                browser.get('https://teams.microsoft.com/_#/calendarv2')    # open calendar tab in teams
-            else:
+            finally:
                 print_msg("checking teams activity again in {} seconds".format(RETRY_WAITOUT), "INFO")
                 sleep(RETRY_WAITOUT)
 
